@@ -3,11 +3,11 @@ package Specio::Constraint::Role::IsaType;
 use strict;
 use warnings;
 
-our $VERSION = '0.45';
+our $VERSION = '0.51';
 
-use Scalar::Util qw( blessed );
+use Clone               ();
+use Scalar::Util        qw( blessed );
 use Specio::PartialDump qw( partial_dump );
-use Storable qw( dclone );
 
 use Role::Tiny;
 
@@ -16,7 +16,7 @@ with 'Specio::Constraint::Role::Interface';
 
 {
     ## no critic (Subroutines::ProtectPrivateSubs)
-    my $attrs = dclone( Specio::Constraint::Role::Interface::_attrs() );
+    my $attrs = Clone::clone( Specio::Constraint::Role::Interface::_attrs() );
     ## use critic
 
     for my $name (qw( parent _inline_generator )) {
@@ -41,7 +41,7 @@ sub _wrap_message_generator {
     my $self      = shift;
     my $generator = shift;
 
-    my $type          = ( split /::/, blessed $self)[-1];
+    my $type          = ( split /::/, blessed $self )[-1];
     my $class         = $self->class;
     my $allow_classes = $self->_allow_classes;
 
@@ -53,13 +53,13 @@ sub _wrap_message_generator {
             return "An undef will never pass an $type check (wants $class)"
                 unless defined $value;
 
-            if ( ref $value && !blessed $value) {
+            if ( ref $value && !blessed $value ) {
                 my $dump = partial_dump($value);
                 return
                     "An unblessed reference ($dump) will never pass an $type check (wants $class)";
             }
 
-            if ( !blessed $value) {
+            if ( !blessed $value ) {
                 return
                     "An empty string will never pass an $type check (wants $class)"
                     unless length $value;
@@ -110,18 +110,17 @@ Specio::Constraint::Role::IsaType - Provides a common implementation for Specio:
 
 =head1 VERSION
 
-version 0.45
+version 0.51
 
 =head1 DESCRIPTION
 
-See L<Specio::Constraint::AnyIsa> and L<Specio::Constraint::ObjectIsa> for details.
+See L<Specio::Constraint::AnyIsa> and L<Specio::Constraint::ObjectIsa> for
+details.
 
 =head1 SUPPORT
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -132,7 +131,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2019 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2025 by Dave Rolsky.
 
 This is free software, licensed under:
 
